@@ -1,11 +1,17 @@
 import copy
 import pickle
 from typing import List
+
 import numpy as np
 import pandas as pd
 from pandas.core.tools.datetimes import _guess_datetime_format_for_array
 from tqdm import tqdm
 
+from structured_data_profiling.data_slicing import (
+    check_column_balance,
+    feature_importance,
+    find_slices,
+)
 from structured_data_profiling.data_tests import (
     check_precision,
     column_a_greater_than_b,
@@ -17,13 +23,6 @@ from structured_data_profiling.data_tests import (
     get_label_correlation,
     identify_dates,
 )
-
-from structured_data_profiling.data_slicing import (
-    feature_importance,
-    find_slices,
-    check_column_balance,
-)
-
 from structured_data_profiling.expectations import (
     add_column_expectations,
     add_conditional_expectations,
@@ -119,7 +118,11 @@ class DatasetProfiler:
         if n_samples is None:
             n_samples = int(0.1 * df.shape[0])
 
-        samples = np.random.choice(df.shape[0], min(n_samples, df.shape[0]), replace=False)
+        samples = np.random.choice(
+            df.shape[0],
+            min(n_samples, df.shape[0]),
+            replace=False,
+        )
         self.n_samples = n_samples
         self.samples = samples
 
@@ -183,7 +186,7 @@ class DatasetProfiler:
                     self.reduced_data_sample[i].sample(10).values,
                 )
                 self.datetime_formats[i] = format_time
-            except:
+            except Exception:
                 self.datetime_formats[i] = "Could not infer datetime format"
 
         self.tests = None
@@ -229,7 +232,7 @@ class DatasetProfiler:
 
         try:
             self.slice_data()
-        except:
+        except Exception:
             print("Could not find data slices.")
 
         print("Profiling finished.")
@@ -437,7 +440,7 @@ class DatasetProfiler:
                 [
                     i
                     for i in num_cols
-                    if self.column_profiles[i]["non_negative"] == True
+                    if self.column_profiles[i]["non_negative"] is True
                 ],
             ),
         ]
@@ -447,7 +450,7 @@ class DatasetProfiler:
                 [
                     i
                     for i in num_cols
-                    if self.column_profiles[i]["non_positive"] == True
+                    if self.column_profiles[i]["non_positive"] is True
                 ],
             ),
         ]
@@ -481,30 +484,43 @@ class DatasetProfiler:
         data_tests = {}
         xp = self.prepro.transform(self.reduced_data_sample)
         xp_nan = self.prepro.transform_missing(self.reduced_data_sample)
-
-        data_tests["is_greater_than"] = column_a_greater_than_b(
-            self.reduced_data_sample,
-            self.column_types,
-            t=0.95,
-        )
+        try:
+            data_tests["is_greater_than"] = column_a_greater_than_b(
+                self.reduced_data_sample,
+                self.column_types,
+                t=0.95,
+            )
+        except:
+            print("Could not complete is_greater_than tests.")
+            data_tests["is_greater_than"] = None
 
         print("Finding bi-variate tests...")
-        bivariate_tests = get_label_correlation(
-            xp,
-            self.prepro.cat_cols,
-            p_tr=0.66,
-            delta_tr=0.05,
-        )
-        data_tests["bivariate_tests"] = bivariate_tests
+        try:
+            bivariate_tests = get_label_correlation(
+                xp,
+                self.prepro.cat_cols,
+                p_tr=0.66,
+                delta_tr=0.05,
+            )
+            data_tests["bivariate_tests"] = bivariate_tests
+
+        except:
+            print("Could not complete bivariate tests.")
+            data_tests["bivariate_tests"] = None
+
         print("Finding missing-values tests...")
+        try:
+            missing_values_tests = get_label_correlation(
+                xp_nan,
+                self.prepro.nan_cols,
+                p_tr=0.66,
+                delta_tr=0.05,
+            )
+            data_tests["missing_values_tests"] = missing_values_tests
+        except:
+            print("Could not complete missing_values_tests tests.")
+            data_tests["missing_values_tests"] = None
 
-        missing_values_tests = get_label_correlation(
-            xp_nan,
-            self.prepro.nan_cols,
-            p_tr=0.66,
-            delta_tr=0.05,
-        )
-        data_tests["missing_values_tests"] = missing_values_tests
         """
         cat_columns = self.reduced_data_sample.columns[
             self.reduced_data_sample.dtypes == "object"
@@ -536,18 +552,21 @@ class DatasetProfiler:
             )
             data_tests["deterministic_columns_binary"] = deterministic_columns_binary
             to_drop = [i[0] for i in deterministic_columns_binary]
-        except:
+        except Exception:
             data_tests["deterministic_columns_binary"] = []
             to_drop = []
 
         print("Finding linear combinations...")
 
         self.reduced_data_sample = self.reduced_data_sample.drop(to_drop, axis=1)
-        linear_combinations, num_cols = find_deterministic_columns_regression(
-            self.reduced_data_sample,
-        )
-        data_tests["linear_combinations"] = linear_combinations
-
+        try:
+            linear_combinations, num_cols = find_deterministic_columns_regression(
+                self.reduced_data_sample,
+            )
+            data_tests["linear_combinations"] = linear_combinations
+        except:
+            print("Could not complete linear_combinations tests.")
+            data_tests["linear_combinations"] = None
         return data_tests
 
     def slice_data(self):
